@@ -6,7 +6,7 @@ mod tests;
 use nom::{
     branch::alt,
     bytes::complete::{tag, take_till1},
-    character::complete::{alphanumeric1, char, multispace0, multispace1},
+    character::complete::{alphanumeric1, char, multispace1},
     combinator::opt,
     error::Error,
     multi::{many0, separated_list0},
@@ -17,15 +17,17 @@ use std::{
     fmt::{Display, Formatter},
     ops::{Add, AddAssign},
 };
+
 ///
 pub fn parse_tailwind(input: &str) -> Result<Vec<AstStyle>, Err<Error<&str>>> {
-    let groups = match tuple((multispace0, many0(tuple((AstGroupItem::parse, multispace0)))))(input)
-    {
-        Ok(o) => o.1.1,
+    let rest = many0(tuple((multispace1, AstGroupItem::parse)));
+    let (head, groups) = match tuple((AstGroupItem::parse, rest))(input.trim()) {
+        Ok(o) => o.1,
         Err(e) => return Err(e),
     };
     let mut out = vec![];
-    for (g, _) in groups {
+    head.expand(&mut out);
+    for (_, g) in groups {
         g.expand(&mut out)
     }
     Ok(out)
