@@ -2,7 +2,7 @@
 #![deny(missing_copy_implementations)]
 #![deny(missing_docs)]
 #![deny(rustdoc::missing_crate_level_docs)]
-#![doc = include_str!("../readme.md")]
+#![doc = include_str!("../Readme.md")]
 #![doc(html_logo_url = "https://upload.wikimedia.org/wikipedia/commons/d/d5/Tailwind_CSS_Logo.svg")]
 #![doc(
     html_favicon_url = "https://upload.wikimedia.org/wikipedia/commons/d/d5/Tailwind_CSS_Logo.svg"
