@@ -16,7 +16,7 @@ where
 {
     map_res(recognize(digit1), str::parse)(input)
 }
-
+///
 pub fn parse_i_px_maybe<T>(input: &str) -> IResult<&str, T>
 where
     T: FromStr,
@@ -30,7 +30,7 @@ pub fn parse_f32(input: &str) -> IResult<&str, f32> {
     let float1 = tuple((digit1, opt(tuple((tag("."), digit1)))));
     map_res(recognize(float1), str::parse)(input)
 }
-
+///
 pub fn parse_f_percent(input: &str) -> IResult<&str, f32> {
     let (rest, (f, _)) = tuple((parse_f32, char('%')))(input)?;
     Ok((rest, f))
@@ -42,5 +42,24 @@ pub fn parse_fraction(input: &str) -> IResult<&str, (usize, usize)> {
     Ok((rest, (a, b)))
 }
 
+/// 100(/50)?
+#[inline]
+pub fn parse_fraction_maybe(input: &str) -> IResult<&str, (usize, Option<usize>)> {
+    let (rest, (a, b)) = tuple((parse_integer, opt(tuple((tag("/"), parse_integer)))))(input)?;
+    Ok((rest, (a, b.map(|s| s.1))))
+}
+
 /// #50d71e
 pub fn parser_color_hex() {}
+
+// fn hex3() {
+//
+// }
+//
+// fn hex6() {
+//
+// }
+//
+// fn hex8() {
+//
+// }
